Module eventloop

Module eventloop 

Structs

CommandRequest
Request to send a command and get reply
EventLoopHandle
Handle to the event loop for sending commands and receiving events.
InFlight
A command that has been handed to the loop and not yet answered.

Functions

spawn_event_loop
Start the event loop task