Module reader

Module reader 

Modules

value_tags
JDWP value tags (JDWP spec, Value / TaggedObjectID). Each is the ASCII code of the JNI type signature character, which is why they look arbitrary as numbers.

Functions

read_i32
Read a i32
read_i64
Read an i64
read_string
Read a JDWP string (4-byte length prefix + UTF-8 bytes)
read_u8
Read a u8
read_u32
Read a u32
read_u64
Read a u64
read_value_by_tag
Read an untagged value whose type is named by a JDWP value tag.
some_if_present
A JDWP string that means “there is none” when it is empty.