Constants
- ALL_
CLASSES - ALL_
THREADS - CAPABILITIES
- CAPABILITIES_
NEW - CLASSES_
BY_ SIGNATURE - CLASS_
PATHS - CREATE_
STRING - DISPOSE
- DISPOSE_
OBJECTS - EXIT
- HOLD_
EVENTS - ID_
SIZES - INSTANCE_
COUNTS - How many live instances each of several types has — one heap walk for the whole batch, which is why the tool takes a list (DISC-10).
- REDEFINE_
CLASSES - RELEASE_
EVENTS - RESUME
- SUSPEND
- TOP_
LEVEL_ THREAD_ GROUPS - VERSION