Structs
- Command
Request - Request to send a command and get reply
- Event
Loop Handle - Handle to the event loop for sending commands and receiving events.
- InFlight
- A command that has been handed to the loop and not yet answered.
Functions
- spawn_
event_ loop - Start the event loop task