Module reader
jdwp_
client
0.20.0
Module reader
Module Items
Modules
Functions
In crate jdwp_
client
jdwp_client
Module
reader
Modules

value_
tags
JDWP value tags (JDWP spec,
Value
/
TaggedObjectID
). Each is the ASCII code of the JNI type signature character, which is why they look arbitrary as numbers.
Functions

read_
i32
Read a i32
read_
i64
Read an i64
read_
string
Read a JDWP string (4-byte length prefix + UTF-8 bytes)
read_u8
Read a u8
read_
u32
Read a u32
read_
u64
Read a u64
read_
value_
by_
tag
Read an untagged value whose type is named by a JDWP value
tag
.
some_
if_
present
A JDWP string that means “there is none” when it is empty.